@@ -102,6 +102,7 @@ if ( !$nc ) {
 
 $dsarray = array ();
 $hnarray = array ();
+$pnarray = array ();
 $sitetag = array (); /* a tag to skip duplicated entries */
 
 for ( $k = 0; $k < $nc; $k++ ) {
@@ -112,6 +113,7 @@ for ( $k = 0; $k < $nc; $k++ ) {
   if ( $clconn && !$sitetag[$clhost] ) {
     array_push($dsarray,$clconn);
     array_push($hnarray,$clhost);
+    array_push($pnarray,$clport);
     $sitetag[$clhost] = 1; /* filtering tag */
   }
 }
@@ -127,8 +129,7 @@ if ( !$nhosts ) {
 // Search all clusters for (a) allowed queues and (b) for user jobs
 
 $uiarray = @ldap_search($dsarray,DN_LOCAL,$filter,$lim,0,0,$tlim,LDAP_DEREF_NEVER,$tout);
-$srarray = @ldap_search($dsarray,DN_LOCAL,$ufilter,$ulim,0,0,$tlim,LDAP_DEREF_NEVER,$tout);
-           
+
 // Loop on results: first go queues
 
 // HTML table initialisation
@@ -138,13 +139,17 @@ $dnmsg    = "<b>".$errors["420"]."</b>: ".$uname;
 $utable->adderror($dnmsg, "#cccccc");
 
 $nauclu = 0;
+$goodds = array();
+$goodhn = array();
+$goodpn = array();
 
 for ( $ids = 0; $ids < $nhosts; $ids++ ) {
 
   $ui    = $uiarray[$ids];
   $hn    = $hnarray[$ids];
+  $pn    = $pnarray[$ids];
   $dst   = $dsarray[$ids];
-  $curl  = popup("clusdes.php?host=$hn&port=2135",700,620,1);
+  $curl  = popup("clusdes.php?host=$hn&port=$pn",700,620,1);
 
   if ($dst && $ui) {
 
@@ -152,6 +157,9 @@ for ( $ids = 0; $ids < $nhosts; $ids++ ) {
     if ($nqueues > 0) {
 
       $nauclu++;
+      array_push($goodds,$dst);
+      array_push($goodhn,$hn);
+      array_push($goodpn,$pn);
 				
       // If there are valid entries, tabulate results
 				
@@ -177,8 +185,11 @@ for ( $ids = 0; $ids < $nhosts; $ids++ ) {
 	    break;
 	  }
 	}
-	$qurl  = popup("quelist.php?host=$ucluster&port=2135&qname=$uqueue",750,430,6);
-	$curl  = popup("clusdes.php?host=$ucluster&port=2135",700,620,1);
+
+	if ( $debug == 2 ) dbgmsg("$hn -- $ucluster<br>");
+
+	$qurl  = popup("quelist.php?host=$ucluster&port=$pn&qname=$uqueue",750,430,6);
+	$curl  = popup("clusdes.php?host=$ucluster&port=$pn",700,620,1);
 	$fcpu  = $allres[$j][USR_CPUS][0];
 	$fproc = freeproc($fcpu);
 	$fdisk = $allres[$j][USR_DISK][0];
@@ -205,15 +216,22 @@ $utable->adderror("<font color=\"#ffffff\"><i><b>".$errors["421"].$nauclu.$error
 $utable->close();
 echo "<br>\n";
 
+$srarray = @ldap_search($goodds,DN_LOCAL,$ufilter,$ulim,0,0,$tlim,LDAP_DEREF_NEVER,$tout);
+
 // HTML table initialisation
 $jtable  = new LmTable($module,$toppage->$module);
 $rowcont = array();
 $jcount  = 0;
-				
-for ( $ids = 0; $ids < $nhosts; $ids++ ) {
+
+$nghosts = count($goodds);
+
+for ( $ids = 0; $ids < $nghosts; $ids++ ) {
 
   $sr  = $srarray[$ids];
-  $dst = $dsarray[$ids];
+  $dst = $goodds[$ids];
+  $gpn = $goodpn[$ids];
+  $ghn = $goodhn[$ids];
+
   if ($dst && $sr) {
 			
     // If search returned, check that there are valid entries
@@ -248,9 +266,10 @@ for ( $ids = 0; $ids < $nhosts; $ids++ ) {
 	$ncpus    = ($entries[$i][JOB_CPUS][0]) ? $entries[$i][JOB_CPUS][0] : "";
 	$error    = ($entries[$i][JOB_ERRS][0]);
 	if ( $error ) $error = ( preg_match("/user/i",$error) ) ? "X" : "!";
-	$newwin   = popup("jobstat.php?host=$cluster&port=2135&status=$status&jobdn=$jobdn",750,430,4);
-	$quewin   = popup("quelist.php?host=$cluster&port=2135&qname=$queue",750,430,6);
-	$clstring = popup("clusdes.php?host=$cluster&port=2135",700,620,1);
+	if ( $debug == 2 ) dbgmsg("$ghn --- $cluster<br>");
+	$newwin   = popup("jobstat.php?host=$cluster&port=$gpn&status=$status&jobdn=$jobdn",750,430,4);
+	$quewin   = popup("quelist.php?host=$cluster&port=$gpn&qname=$queue",750,430,6);
+	$clstring = popup("clusdes.php?host=$cluster&port=$gpn",700,620,1);
 	$jcount++;
 					
 	// filling the table
