@@ -37,9 +37,16 @@ $vos = array (
 		     ),
 	      array (
 		     "name"   => "NorduGrid guests",
-		     "server" => "grid-vo.nordugrid.org",
-		     "port"   => "389",
-		     "dn"     => "ou=guests,dc=nordugrid,dc=org"
+		     "server" => "https://www.pdc.kth.se/grid/swegrid-vo",
+		     "port"   => "",
+		     "dn"     => "vo.ng-guest-vo"
+		     ),
+	      array (
+		     "name"   => "NorduGrid developers",
+		     "server" => "http://www.nordugrid.org",
+		     "port"   => "",
+		     "dn"     => "",
+		     "group"  => "developers.dn"
 		     ),
 	      array (
 		     "name"   => "NorduGrid tutorials",
@@ -47,6 +54,13 @@ $vos = array (
 		     "port"   => "389",
 		     "dn"     => "ou=tutorial,dc=nordugrid,dc=org"
 		     ),
+	      array (
+		     "name"   => "ATLAS test users (SWEGRID)",
+		     "server" => "https://www.pdc.kth.se",
+		     "port"   => "",
+		     "dn"     => "",
+		     "group"  => "grid/swegrid-vo/vo.atlas-testusers-vo"
+		     ),
 	      /*
 	      array (
 		     "name"   => "NorduGrid services",
@@ -73,6 +87,13 @@ $vos = array (
 		     "port"   => "389",
 		     "dn"     => "o=atlas,dc=eu-datagrid,dc=org"
 		     ),
+	      array (
+		     "name"   => "LCG ATLAS",
+		     "server" => "grid-vo.nikhef.nl",
+		     "port"   => "389",
+		     "dn"     => "o=atlas,dc=eu-datagrid,dc=org",
+		     "group"  => "ou=lcg1"
+		     ),	      
 	      array (
 		     "name"   => "EDG CMS",
 		     "server" => "grid-vo.nikhef.nl",
@@ -151,26 +172,34 @@ foreach ( $vos as $contact ) {
   $group     = $contact["group"];
 
   $nusers    = "";
-  $ds = ldap_connect($server,$port);
-  if ($ds) {
-    if ( $group ) {
-      $newfilter = "(objectclass=*)";
-      $newdn     = $group.",".$dn;
-      $newlim    = array("dn","member");
-      $sr        = @ldap_search($ds,$newdn,$newfilter,$newlim,0,0,10,LDAP_DEREF_NEVER,10);
-      $groupdesc = @ldap_get_entries($ds,$sr);
-      $nusers    = $groupdesc[0]["member"]["count"];
-    } else {
-      $sr = @ldap_search($ds,$dn,"(objectclass=organizationalPerson)",array("dn"),0,0,10,LDAP_DEREF_NEVER,10);
-      if ($sr) $nusers = @ldap_count_entries($ds,$sr);
-    }
-  }
 
-  $vostring  = popup("vo-users.php?host=$server&port=$port&vo=$dn&group=$group",750,300,6);
+  if ( $dn ) { // open ldap connection
+    $ds = ldap_connect($server,$port);
+    if ($ds) {
+      if ( $group ) {
+	$newfilter = "(objectclass=*)";
+	$newdn     = $group.",".$dn;
+	$newlim    = array("dn","member");
+	$sr        = @ldap_search($ds,$newdn,$newfilter,$newlim,0,0,10,LDAP_DEREF_NEVER,10);
+	$groupdesc = @ldap_get_entries($ds,$sr);
+	$nusers    = $groupdesc[0]["member"]["count"];
+      } else {
+	$sr = @ldap_search($ds,$dn,"(objectclass=organizationalPerson)",array("dn"),0,0,10,LDAP_DEREF_NEVER,10);
+	if ($sr) $nusers = @ldap_count_entries($ds,$sr);
+      }
+    }
+    $vostring  = popup("vo-users.php?host=$server&port=$port&vo=$dn&group=$group",750,300,6);
+  } else {
+    $url = $server."/".$group;
+    $users = file($url);
+    $nusers = count($users);
+    $vostring = popup($url,750,300,6);
+  }
+  
   $rowcont[] = "<a href=\"$vostring\">".$contact["name"]."</a>";
   $rowcont[] = $nusers;
   $rowcont[] = $server;
-
+  
   $votable->addrow($rowcont);
   $rowcont = array ();
 }
